summaryrefslogtreecommitdiffstats
path: root/src/kcm/configdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kcm/configdialog.cpp')
-rw-r--r--src/kcm/configdialog.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/kcm/configdialog.cpp b/src/kcm/configdialog.cpp
index 3118ce6..589c65e 100644
--- a/src/kcm/configdialog.cpp
+++ b/src/kcm/configdialog.cpp
@@ -269,7 +269,7 @@ void ConfigDialog::load()
// select the backend from the config file
bool foundBackend = false;
- TQString backend = config->readEntry( "Backend", "Nettools" );
+ TQString backend = config->readEntry( "Backend", "Sys" );
int i;
for ( i = 0; KCMRegistry[i].name != TQString(); i++ )
{
@@ -282,7 +282,7 @@ void ConfigDialog::load()
if ( !foundBackend )
{
- i = 0; // use the first backend (Nettools)
+ i = 0; // use the first backend (Sys)
}
mDlg->comboBoxBackends->setCurrentItem( i );
mDlg->textLabelBackendDescription->setText( KCMRegistry[i].description );